==> dolfin-0.9.2.tar.gz: dolfin-0.9.2/dolfin/la/PETScLUSolver.h <==
// Copyright (C) 2005-2006 Anders Logg.
// Licensed under the GNU LGPL Version 2.1.
//
// First added:  2005
// Last changed: 2006-08-15

#ifndef __PETSC_LU_SOLVER_H
#define __PETSC_LU_SOLVER_H

#ifdef HAS_PETSC

#include <petscmat.h>
#include <petscksp.h>
#include "GenericLinearSolver.h"
#include "PETScVector.h"

namespace dolfin
{
  /// Forward declarations
  class GenericMatrix;
  class GenericVector;
  class PETScManager;
  class PETScMatrix;
  class PETScKrylovMatrix;

  /// This class implements the direct solution (LU factorization) for
  /// linear systems of the form Ax = b. It is a wrapper for the LU
  /// solver of PETSc.
  
  class PETScLUSolver : public GenericLinearSolver
  {
  public:
    
    /// Constructor
    PETScLUSolver();

    /// Destructor
    ~PETScLUSolver();

    /// Solve linear system Ax = b
    uint solve(const GenericMatrix& A, GenericVector& x, const GenericVector& b);

    /// Solve linear system Ax = b
    uint solve(const PETScMatrix& A, PETScVector& x, const PETScVector& b);

    /// Solve linear system Ax = b
    uint solve(const PETScKrylovMatrix& A, PETScVector& x, const PETScVector& b);

    /// Display LU solver data
    void disp() const;

  private:
    
    // Initialise solver
    void init();
    
    // Clear data
    void clear();

    // Create dense copy of virtual matrix
    double copyToDense(const PETScKrylovMatrix& A);

    KSP ksp;

    Mat B;
    int* idxm;
    int* idxn;

    PETScVector e;
    PETScVector y;
  };

}

#endif

#endif

==> dolfin-0.9.6.tar.gz: dolfin-0.9.6/dolfin/la/PETScLUSolver.h <==
// Copyright (C) 2005-2006 Anders Logg.
// Licensed under the GNU LGPL Version 2.1.
//
// Modified by Garth N. Wells, 2009.
//
// First added:  2005
// Last changed: 2009-09-08

#ifndef __PETSC_LU_SOLVER_H
#define __PETSC_LU_SOLVER_H

#ifdef HAS_PETSC

#include <petscmat.h>
#include <petscksp.h>
#include "GenericLinearSolver.h"
#include "PETScVector.h"

namespace dolfin
{
  /// Forward declarations
  class GenericMatrix;
  class GenericVector;
  class PETScMatrix;
  class PETScKrylovMatrix;

  /// This class implements the direct solution (LU factorization) for
  /// linear systems of the form Ax = b. It is a wrapper for the LU
  /// solver of PETSc.

  class PETScLUSolver : public GenericLinearSolver
  {
  public:

    /// Constructor
    PETScLUSolver();

    /// Destructor
    ~PETScLUSolver();

    /// Solve linear system Ax = b
    uint solve(const GenericMatrix& A, GenericVector& x, const GenericVector& b);

    /// Solve linear system Ax = b
    uint solve(const PETScMatrix& A, PETScVector& x, const PETScVector& b);

    /// Solve linear system Ax = b
    uint solve(const PETScKrylovMatrix& A, PETScVector& x, const PETScVector& b);

    /// Return informal string representation (pretty-print)
    std::string str(bool verbose) const;

    /// Default parameter values
    static Parameters default_parameters();

  private:

    // Initialise solver
    void init();

    // Clear data
    void clear();

    // Create dense copy of virtual matrix
    double copy_to_dense(const PETScKrylovMatrix& A);

    KSP ksp;

    Mat B;
    int* idxm;
    int* idxn;

    PETScVector e;
    PETScVector y;

  };

}

#endif

#endif
